@@ -370,6 +370,22 @@ class PipeEdge(EdgeModel):
         )
 
 
+class PumpEdge(EdgeModel):
+    """Edge model representing a pump of pandapipes"""
+
+    def values_as_dict(self):
+        return self._network.res_pump.loc[self._id]
+
+    def component_type(self):
+        return "pump"
+
+    def name(self):
+        return self._network.pump[NAME_KEY][self._id]
+
+    def loss_perc(self):
+        return 0
+
+
 class CircPumpPressureEdge(EdgeModel):
     """Edge model representing a circ_pump_pressure of pandapipes"""
 
