@@ -1,6 +1,14 @@
 import simbench
 
 import peext.scenario.network as ps
+import pandapipes.multinet.control as ppmc
+
+
+def test_convergence_simple_network():
+    mn = ps.create_small_test_multinet()
+
+    # pandapipes error makes this test impossible right now
+    ppmc.run_control_multinet.run_control(mn, max_iter=30, mode="all")
 
 
 def test_convergence_coupled_district_network():
